@@ -2,11 +2,12 @@ from dataclasses import dataclass
 
 from dataclasses_json import dataclass_json
 from .auth_request import AuthRequest
+from .fields import default
 
 
 @dataclass_json
 @dataclass
 class VoteRequest:
-    auth: AuthRequest
-    direction: bool
-    hash: str
+    auth: AuthRequest = default()
+    direction: bool = default()
+    hash: str = default()
